import {
  select,
  csv,
  axisLeft,
  axisBottom,
  scaleOrdinal,
  format,
  schemeSpectral
} from 'd3';

import { loadAndProcessData } from './loadAndProcessData';
import { scatterPlot } from './scatterPlot';
import { colorLegend } from './colorLegend';

 
const svg = select('svg');
const scatterPlotG = svg.append('g');
const colorLegendG = svg.append('g')
    .attr('transform',`translate(810,25)`);

const width = +svg.attr('width'); 
const height = +svg.attr('height');

const title = 'Cars: Horsepower vs. Weight';
const xValue = d => d.horsepower;
const xAxisLabel = 'Horsepower';
const yValue = d => d.weight;
const circleRadius = 6;
const yAxisLabel = 'Weight';
const margin = { top: 100, right: 40, bottom: 88, left: 150 };
const colorScale = scaleOrdinal(); 
const colorValue = data => data.origin;

let selectedColorValue;
let data;
 
const onClick = d => {
  selectedColorValue = d;
  render(); 
}
loadAndProcessData()
  .then(d => {
    data = d
    render() 
  }); 

const render = () => { 
  
  colorScale
    .domain(data.map(colorValue))
    .domain(colorScale.domain().sort().reverse())
    .range(schemeSpectral[colorScale.domain().length]);
  
  scatterPlotG.call(scatterPlot,{
    data,
    width,
    height,
    margin,
    title,
    xValue,
    xAxisLabel,
    yValue,
    yAxisLabel, 
    circleRadius,
    colorValue,
    colorScale,
    selectedColorValue
  });
  
  colorLegendG.call(colorLegend,{
    colorScale,
    circleRadius: 10,
    spacing: 26,
    textOffset: 12,
    backgroundRectWidth:130,
    onClick,
    selectedColorValue
  });
};



